import React, { useState, useEffect, useCallback } from "react";
import PropTypes from "prop-types";
import TableChartIcon from "@material-ui/icons/TableChart";
import ViewListIcon from "@material-ui/icons/ViewList";
import ToggleButton from "@material-ui/lab/ToggleButton";
import ToggleButtonGroup from "@material-ui/lab/ToggleButtonGroup";
import { Tooltip } from "@material-ui/core";
import { useWindowSize } from "@flare/react-hooks";
import { useTranslation } from "react-i18next";

export const ViewModes = {
  TABLE: "table",
  ACCORDION: "accordion"
};

const ViewModeSelection = ({ callback }) => {
  const [state, setState] = useState({
    mode: ViewModes.TABLE,
    manual: false
  });
  const { isMobile } = useWindowSize();
  const { t } = useTranslation();

  const handleViewModeSelection = useCallback(
    (event, mode) => {
      setState({ mode, manual: true });
      callback && callback(mode);
    },
    [callback]
  );

  useEffect(() => {
    if (state.manual === true) return;
    const mode = isMobile ? ViewModes.ACCORDION : ViewModes.TABLE;
    setState({ mode, manual: false });
    callback && callback(mode);
  }, [callback, isMobile, state.manual]);

  return (
    <ToggleButtonGroup
      size="small"
      value={state.mode}
      exclusive
      onChange={handleViewModeSelection}
    >
      <ToggleButton value={ViewModes.TABLE} aria-label="table view mode">
        <Tooltip title={t("ViewModes.Table")}>
          <TableChartIcon />
        </Tooltip>
      </ToggleButton>
      <ToggleButton
        value={ViewModes.ACCORDION}
        aria-label="accordion view mode"
      >
        <Tooltip title={t("ViewModes.List")}>
          <ViewListIcon />
        </Tooltip>
      </ToggleButton>
    </ToggleButtonGroup>
  );
};

ViewModeSelection.propTypes = {
  initialMode: PropTypes.oneOf([ViewModes.TABLE, ViewModes.ACCORDION]),
  callback: PropTypes.func
};

export default ViewModeSelection;
