import React, { useMemo } from "react";
import PropTypes from "prop-types";
import WakeComponent from "./WakeComponent";
import ActionButton from "./ActionButton";
import { Menu } from "@material-ui/core";

const ActionsGroup = ({
  machine,
  actions,
  addLog,
  secondaryActionsMenuProps
}) => {
  const topActions = useMemo(
    () => actions.filter(a => a.top === true),
    [actions]
  );

  const secondaryActions = useMemo(
    () => actions.filter(a => a.top === false),
    [actions]
  );

  return (
    <>
      <WakeComponent machine={machine} addLog={addLog} />
      {topActions.map(action => (
        <ActionButton
          key={`machine-item-${machine.machineId}-${action.code}`}
          action={action}
          machine={machine}
        />
      ))}
      <Menu
        id="secondary-actions-menu"
        anchorEl={secondaryActionsMenuProps.anchor}
        keepMounted
        open={Boolean(secondaryActionsMenuProps.anchor)}
        onClose={secondaryActionsMenuProps.onCloseSecondaryActions}
      >
        {secondaryActions.map(action => (
          <ActionButton
            key={`machine-item-${machine.machineId}-${action.code}`}
            action={action}
            machine={machine}
          />
        ))}
      </Menu>
    </>
  );
};

ActionsGroup.propTypes = {
  machine: PropTypes.shape({
    machineId: PropTypes.number.isRequired,
    machineName: PropTypes.string.isRequired,
    fullMachineName: PropTypes.string.isRequired,
    macAddress: PropTypes.string.isRequired,
    iPv4Address: PropTypes.string,
    description: PropTypes.string
  }).isRequired,
  actions: PropTypes.array.isRequired,
  addLog: PropTypes.func.isRequired,
  secondaryActionsMenuProps: PropTypes.object.isRequired
};

export default ActionsGroup;
